@@ -60,9 +60,9 @@
   # 
   #  x <- mixmodCluster(as.data.frame(data),seq(2*log(nrow(data))),strategy = mixmodStrategy(seed=123))
   # statdoc of mixmod recommends ceiling(nrow(data)^0.3) and refers to Bozdogan93
-  models <- mixmodGaussianModel(listModels=Infusion.getOption("mixmodGaussianModel"))
-  x <- suppressWarnings(mixmodCluster(as.data.frame(data), nbCluster=nbCluster, models=models, 
-                                      strategy = mixmodStrategy(seed=123)))
+  models <- .mixclustWrap("mixmodGaussianModel",list(listModels=Infusion.getOption("mixmodGaussianModel")))
+  x <- suppressWarnings(.mixclustWrap("mixmodCluster",list(data=as.data.frame(data), nbCluster=nbCluster, models=models, 
+                                                        seed=123) ))
   if (length(nbCluster)==1L) {
     resu <- x@bestResult
     if (x@error) {
@@ -72,8 +72,8 @@
         message("Trying decreasing nbCluster...")
       }
       for (nb in rev(seq_len(min(nbCluster)-1L))) {
-        x <- suppressWarnings(mixmodCluster(as.data.frame(data), nbCluster=nb, models=models, 
-                                            strategy = mixmodStrategy(seed=123)))
+        x <- suppressWarnings(.mixclustWrap("mixmodCluster",list(data=as.data.frame(data), nbCluster=nb, models=models, 
+                                            seed=123) ))
         if ( ! x@error ) break
       }
     } 
@@ -217,3 +217,23 @@ predict.dMixmod <- function(object,
   if (nsim==1L) simuls <- simuls[[1L]]
   return(simuls)
 }
+
+.mixclustWrap <- function(chr_fnname,arglist, pack="Rmixmod") {
+  #eval(as.call(c(quote(require),list(package="Rmixmod", quietly = TRUE))))
+  if (length(grep(pack,packageDescription("Infusion")$Imports))) {
+    ## then the necessary functions must be imported-from in the NAMESPACE  
+    do.call(chr_fnname,arglist) ## "stuff"
+  } else if (length(grep(pack,packageDescription("Infusion")$Suggests))) {
+    ## then the necessary functions cannot be imported-from in the NAMESPACE  (and the package must be written in an appropriate way)
+    if ( requireNamespace(pack, quietly = TRUE)) {
+      #eval(as.call(c(chr_fnname,arglist))) # quote(stuff)
+      myfun <- get(chr_fnname, asNamespace(pack)) ## https://stackoverflow.com/questions/10022436/do-call-in-combination-with
+      do.call(myfun,arglist) ## "stuff"
+    } else {stop(paste("'",pack,"' required but not available.",sep=""))}
+  } else { ## package not declared in DESCRIPTION; to circumvent possible archiving of Rmixmod
+    if (do.call("require",list(package=pack, quietly = TRUE))) {
+      #eval(as.call(c(chr_fnname,arglist))) # quote(stuff)
+      do.call(chr_fnname,arglist) ## "stuff"
+    } else {stop(paste("'",pack,"' required but not available.",sep=""))}
+  }
+}
