@@ -1,9 +1,9 @@
 ## auxiliary fn for sample_volume, tiself for rparam
-`sample_vertices` <- function(n,tryn,vertices,object,fixed=NULL,fittedPars,useEI)  {
+.sample_vertices <- function(n,tryn,vertices,object,fixed=NULL,fittedPars,useEI)  {
   if (length(fittedPars)>length(fixed)) { ## profile CIs, or 
     if (length(fixed)>0L) {
       fixedPars <- names(fixed)
-      if (is.null(fixedPars)) {stop("'fixed' argument of 'sample_vertices' has no name. Check call.")}
+      if (is.null(fixedPars)) {stop("'fixed' argument of '.sample_vertices' has no name. Check call.")}
       subHull <- subHullWrapper(vertices=vertices,equality=fixed)
       if (is.null(subHull$vertices)) {
         return(NULL)
@@ -37,10 +37,10 @@
       Qmax <- object$Qmax
     }
     if (useEI && nrow(trypoints)>n) { ## nrow(trypoints)>n may be FALSE in the degenerate case where trypoints = unique(subHull$vertices)
-      expectedImprovement <- calc_EI(object,trypoints,Qmax=Qmax)  
+      expectedImprovement <- .calc_EI(object,trypoints,Qmax=Qmax)  
       trypoints <- cbind(trypoints,EI=expectedImprovement)
       trypoints <- trypoints[order(trypoints[,"EI"],decreasing=TRUE)[seq_len(n)],fittedPars,drop=FALSE]
-    } else if (tryn>n) {warning("From sample_vertices(): 'tryn'>'n' is uselessly time-consuming.")}
+    } else if (tryn>n) {warning("From .sample_vertices(): 'tryn'>'n' is uselessly time-consuming.")}
   } else {
     ## in one parameter model there is no tengant subspace of proiled out params to investigate
     ## using EI on CI variable would tend to select points towards the MSLE
@@ -92,18 +92,18 @@
     ## if there is only one uppervertice, sample_vertices will typically sample only one point constructed from fixed and that vertice
     ## => test to avoid that; but more general pb must be caught by the test:
     if (nrow(uppervertices)>ncol(vertices)) { 
-      trypoints <- sample_vertices(n,tryn,vertices=uppervertices,object=object,
+      trypoints <- .sample_vertices(n,tryn,vertices=uppervertices,object=object,
                                    fixed=fixed,fittedPars=fittedPars,useEI=useEI) ## can be NULL
     } else  trypoints <- NULL
   } else {
     if ( is.null(vertices)) vertices <- object$fit$data[,fittedPars,drop=FALSE]
     trypoints <- NULL
   }
-  if (is.null(trypoints)) trypoints <- sample_vertices(n,tryn,vertices=vertices,object=object,
+  if (is.null(trypoints)) trypoints <- .sample_vertices(n,tryn,vertices=vertices,object=object,
                                                        fixed=fixed,fittedPars=fittedPars,useEI=useEI)
   oldn <- NROW(trypoints)
   trypoints <- unique(trypoints)
-  if (NROW(trypoints) < oldn) {warning("From sample_volume(): Suspect event: replicate points generated by sample_vertices(). ")}
+  if (NROW(trypoints) < oldn) {warning("From sample_volume(): Suspect event: replicate points generated by .sample_vertices(). ")}
   #  attr(trypoints,"vT") <- vT
   colnames(trypoints) <- fittedPars
   return(trypoints) ## fittedPars parameters
@@ -151,7 +151,7 @@ rparam <- function(object, n= 1, useEI = list(max=TRUE,profileCI=TRUE,rawCI=FALS
   largervT <- volTriangulation(rbind(pts,largerpts))
   #
   if (useCI) {
-    trypoints <- allCIs(object,level=0.1,verbose=FALSE)$bounds ## narrow bracketing of $optr$par by level=0.1
+    trypoints <- .allCIs(object,level=0.1,verbose=FALSE)$bounds ## narrow bracketing of $optr$par by level=0.1
     if (nvec["MSL"]<NROW(trypoints)) { 
       trypoints <- trypoints[sample(nrow(trypoints),nvec["MSL"]),,drop=FALSE]
     } 
@@ -167,8 +167,8 @@ rparam <- function(object, n= 1, useEI = list(max=TRUE,profileCI=TRUE,rawCI=FALS
   }
     # points targeting CI bounds
   if (useCI) {
-    if (is.null(object$CIobject))  object$CIobject <- allCIs(object,level=level,verbose=FALSE)
-    auxCIobject <- allCIs(object,level=1-((1-object$CIobject$level)*2/3),verbose=FALSE)
+    if (is.null(object$CIobject))  object$CIobject <- .allCIs(object,level=level,verbose=FALSE)
+    auxCIobject <- .allCIs(object,level=1-((1-object$CIobject$level)*2/3),verbose=FALSE)
     CIpoints <- object$CIobject$bounds
     ## those for which the bound is present:
     for (kt in seq_len(NROW(CIpoints))) { 
